PhiaUi.Components.Layout.SectionFooter (phia_ui v0.1.17)

Copy Markdown View Source

Section-ending divider with action row.

Typically placed at the bottom of a content section to provide pagination, save buttons, or navigation actions.

Examples

<.section_footer>
  <.button variant={:outline}>Cancel</.button>
  <.button>Save</.button>
</.section_footer>

<.section_footer align={:between}>
  <span class="text-sm text-muted-foreground">Showing 1-10 of 50</span>
  <.pagination ... />
</.section_footer>

<.section_footer divider={false} align={:end}>
  <.button>Next</.button>
</.section_footer>

Summary

Functions

section_footer(assigns)

Attributes

  • divider (:boolean) - Show top border. Defaults to true.
  • align (:atom) - Defaults to :end. Must be one of :start, :center, :end, or :between.
  • class (:string) - Defaults to nil.
  • Global attributes are accepted.

Slots

  • inner_block (required)