Phoenix Endpoint for the PhiaUI Design tool.
Runs on a dedicated port (default 4200), completely independent of the host application's endpoint. All configuration is programmatic — no config files are required.
Static assets
Three Plug.Static mounts serve the required JavaScript:
/assets— the design tool's own JS (hooks, bootstrap)./assets/vendor/phoenix— the pre-built Phoenix channel client from thephoenixdependency./assets/vendor/phoenix_live_view— the pre-built LiveView client from thephoenix_live_viewdependency.
This avoids any build step or bundler while still getting correct LiveView WebSocket transport.
Summary
Functions
Callback implementation for Phoenix.Endpoint.broadcast/3.
Callback implementation for Phoenix.Endpoint.broadcast!/3.
Callback implementation for Phoenix.Endpoint.broadcast_from/4.
Callback implementation for Phoenix.Endpoint.broadcast_from!/4.
Callback implementation for Plug.call/2.
Returns the child specification to start the endpoint under a supervision tree.
Returns the endpoint configuration for key
Reloads the configuration given the application environment changes.
Returns the host for the given endpoint.
Callback implementation for Plug.init/1.
Callback implementation for Phoenix.Endpoint.local_broadcast/3.
Callback implementation for Phoenix.Endpoint.local_broadcast_from/4.
Generates the path information when routing to this endpoint.
Generates the script name.
Returns the address and port that the server is running on
Starts the endpoint supervision tree.
Generates a base64-encoded cryptographic hash (sha512) to a static file
in priv/static. Meant to be used for Subresource Integrity with CDNs.
Returns a two item tuple with the first item being the static_path
and the second item being the static_integrity.
Generates a route to a static file in priv/static.
Generates the static URL without any path information.
Generates the endpoint base URL but as a URI struct.
Callback implementation for Phoenix.Endpoint.subscribe/2.
Callback implementation for Phoenix.Endpoint.unsubscribe/1.
Generates the endpoint base URL without any path information.
Functions
Callback implementation for Phoenix.Endpoint.broadcast/3.
Callback implementation for Phoenix.Endpoint.broadcast!/3.
Callback implementation for Phoenix.Endpoint.broadcast_from/4.
Callback implementation for Phoenix.Endpoint.broadcast_from!/4.
Callback implementation for Plug.call/2.
Returns the child specification to start the endpoint under a supervision tree.
Returns the endpoint configuration for key
Returns default if the key does not exist.
Reloads the configuration given the application environment changes.
Returns the host for the given endpoint.
Callback implementation for Plug.init/1.
Callback implementation for Phoenix.Endpoint.local_broadcast/3.
Callback implementation for Phoenix.Endpoint.local_broadcast_from/4.
Generates the path information when routing to this endpoint.
Generates the script name.
Returns the address and port that the server is running on
Starts the endpoint supervision tree.
All other options are merged into the endpoint configuration.
Generates a base64-encoded cryptographic hash (sha512) to a static file
in priv/static. Meant to be used for Subresource Integrity with CDNs.
Returns a two item tuple with the first item being the static_path
and the second item being the static_integrity.
Generates a route to a static file in priv/static.
Generates the static URL without any path information.
It uses the configuration under :static_url to generate
such. It falls back to :url if :static_url is not set.
Generates the endpoint base URL but as a URI struct.
It uses the configuration under :url to generate such.
Useful for manipulating the URL data and passing it to
URL helpers.
Callback implementation for Phoenix.Endpoint.subscribe/2.
Callback implementation for Phoenix.Endpoint.unsubscribe/1.
Generates the endpoint base URL without any path information.
It uses the configuration under :url to generate such.