PhiaUiDesign.Web.Router (phia_ui v0.1.17)

Copy Markdown View Source

Router for the PhiaUI Design tool.

Single-route application: all traffic goes to EditorLive which manages the full editor UI as a single-page LiveView.

Summary

Functions

Callback invoked by Plug on every request.

Callback required by Plug that initializes the router for serving web requests.

Functions

browser(conn, _)

call(conn, opts)

Callback invoked by Plug on every request.

formatted_routes(_)

Callback implementation for Phoenix.VerifiedRoutes.formatted_routes/1.

init(opts)

Callback required by Plug that initializes the router for serving web requests.

verified_route?(_, split_path)

Callback implementation for Phoenix.VerifiedRoutes.verified_route?/2.