Section-ending divider with action row.
Typically placed at the bottom of a content section to provide pagination, save buttons, or navigation actions.
Examples
<.section_footer>
<.button variant={:outline}>Cancel</.button>
<.button>Save</.button>
</.section_footer>
<.section_footer align={:between}>
<span class="text-sm text-muted-foreground">Showing 1-10 of 50</span>
<.pagination ... />
</.section_footer>
<.section_footer divider={false} align={:end}>
<.button>Next</.button>
</.section_footer>