Command-pattern undo/redo stack for scene operations.
Summary
Functions
Check if redo is available
Check if undo is available
Returns a specification to start this module under a supervisor.
Clear all history
Push a command onto the undo stack, clearing redo
Pop the last command from redo stack (returns nil if empty)
Pop the last command from undo stack (returns nil if empty)
Types
@type command() :: {:insert, PhiaUiDesign.Canvas.Node.t()} | {:delete, PhiaUiDesign.Canvas.Node.t()} | {:update, String.t(), map(), map()} | {:move, String.t(), String.t() | nil, String.t() | nil, integer()}
Functions
Check if redo is available
Check if undo is available
Returns a specification to start this module under a supervisor.
See Supervisor.
Clear all history
Push a command onto the undo stack, clearing redo
Pop the last command from redo stack (returns nil if empty)
Pop the last command from undo stack (returns nil if empty)